[vlc-commits] vout/android: rename AWindowHandler_setWindowLayout

Thomas Guillem git at videolan.org
Wed Dec 21 15:12:56 CET 2016


vlc | branch: master | Thomas Guillem <thomas at gllm.fr> | Wed Dec 21 12:53:48 2016 +0100| [12d482b3b43d3b52f2b73067b24d7c2a5fabcc5f] | committer: Thomas Guillem

vout/android: rename AWindowHandler_setWindowLayout

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=12d482b3b43d3b52f2b73067b24d7c2a5fabcc5f
---

 modules/video_output/android/display.c | 19 +++++++++----------
 modules/video_output/android/utils.c   | 16 ++++++++--------
 modules/video_output/android/utils.h   | 10 +++++-----
 3 files changed, 22 insertions(+), 23 deletions(-)

diff --git a/modules/video_output/android/display.c b/modules/video_output/android/display.c
index adb3a5b..d6324d2 100644
--- a/modules/video_output/android/display.c
+++ b/modules/video_output/android/display.c
@@ -158,8 +158,8 @@ static inline int ChromaToAndroidHal(vlc_fourcc_t i_chroma)
     }
 }
 
-static int UpdateWindowSize(vout_display_sys_t *sys, video_format_t *p_fmt,
-                            bool b_cropped)
+static int UpdateVideoSize(vout_display_sys_t *sys, video_format_t *p_fmt,
+                           bool b_cropped)
 {
     unsigned int i_width, i_height;
     unsigned int i_sar_num = 1, i_sar_den = 1;
@@ -179,10 +179,10 @@ static int UpdateWindowSize(vout_display_sys_t *sys, video_format_t *p_fmt,
         i_height = rot_fmt.i_height;
     }
 
-    AWindowHandler_setWindowLayout(sys->p_awh, i_width, i_height,
-                                   rot_fmt.i_visible_width,
-                                   rot_fmt.i_visible_height,
-                                   i_sar_num, i_sar_den);
+    AWindowHandler_setVideoLayout(sys->p_awh, i_width, i_height,
+                                  rot_fmt.i_visible_width,
+                                  rot_fmt.i_visible_height,
+                                  i_sar_num, i_sar_den);
     return 0;
 }
 
@@ -856,7 +856,7 @@ static void Close(vlc_object_t *p_this)
 
     if (sys->embed)
     {
-        AWindowHandler_setWindowLayout(sys->p_awh, 0, 0, 0, 0, 0, 0);
+        AWindowHandler_setVideoLayout(sys->p_awh, 0, 0, 0, 0, 0, 0);
         vout_display_DeleteWindow(vd, sys->embed);
     }
 
@@ -911,7 +911,7 @@ static picture_pool_t *PoolAlloc(vout_display_t *vd, unsigned requested_count)
     requested_count = sys->p_window->i_pic_count;
     msg_Dbg(vd, "PoolAlloc: got %d frames", requested_count);
 
-    UpdateWindowSize(sys, &sys->p_window->fmt, sys->p_window->b_use_priv);
+    UpdateVideoSize(sys, &sys->p_window->fmt, sys->p_window->b_use_priv);
 
     pp_pics = calloc(requested_count, sizeof(picture_t));
 
@@ -1173,8 +1173,7 @@ static int Control(vout_display_t *vd, int query, va_list args)
         } else
             CopySourceAspect(&sys->p_window->fmt, source);
 
-        UpdateWindowSize(sys, &sys->p_window->fmt,
-                         sys->p_window->b_use_priv);
+        UpdateVideoSize(sys, &sys->p_window->fmt, sys->p_window->b_use_priv);
         FixSubtitleFormat(sys);
         return VLC_SUCCESS;
     }
diff --git a/modules/video_output/android/utils.c b/modules/video_output/android/utils.c
index df9c9ca..7bde0c0 100644
--- a/modules/video_output/android/utils.c
+++ b/modules/video_output/android/utils.c
@@ -77,7 +77,7 @@ static struct
         jmethodID getSubtitlesSurface;
         jmethodID setCallback;
         jmethodID setBuffersGeometry;
-        jmethodID setWindowLayout;
+        jmethodID setVideoLayout;
     } AndroidNativeWindow;
     struct {
         jmethodID create;
@@ -455,8 +455,8 @@ InitJNIFields(JNIEnv *env, vlc_object_t *p_obj, jobject *jobj)
                "setCallback", "(J)Z", true);
     GET_METHOD(AndroidNativeWindow.setBuffersGeometry,
                "setBuffersGeometry", "(Landroid/view/Surface;III)Z", true);
-    GET_METHOD(AndroidNativeWindow.setWindowLayout,
-               "setWindowLayout", "(IIIIII)V", true);
+    GET_METHOD(AndroidNativeWindow.setVideoLayout,
+               "setVideoLayout", "(IIIIII)V", true);
 
     GET_SMETHOD(SurfaceTextureThread.create,
                 "SurfaceTextureThread_create",
@@ -705,16 +705,16 @@ AWindowHandler_setBuffersGeometry(AWindowHandler *p_awh, enum AWindow_ID id,
 }
 
 int
-AWindowHandler_setWindowLayout(AWindowHandler *p_awh,
-                               int i_width, int i_height,
-                               int i_visible_width, int i_visible_height,
-                               int i_sar_num, int i_sar_den)
+AWindowHandler_setVideoLayout(AWindowHandler *p_awh,
+                              int i_width, int i_height,
+                              int i_visible_width, int i_visible_height,
+                              int i_sar_num, int i_sar_den)
 {
     JNIEnv *p_env = AWindowHandler_getEnv(p_awh);
     if (!p_env)
         return VLC_EGENERIC;
 
-    JNI_ANWCALL(CallVoidMethod, setWindowLayout, i_width, i_height,
+    JNI_ANWCALL(CallVoidMethod, setVideoLayout, i_width, i_height,
                 i_visible_width,i_visible_height, i_sar_num, i_sar_den);
     return VLC_SUCCESS;
 }
diff --git a/modules/video_output/android/utils.h b/modules/video_output/android/utils.h
index 39fffe9..e1180cb 100644
--- a/modules/video_output/android/utils.h
+++ b/modules/video_output/android/utils.h
@@ -162,12 +162,12 @@ int AWindowHandler_setBuffersGeometry(AWindowHandler *p_awh, enum AWindow_ID id,
                                       int i_width, int i_height, int i_format);
 
 /**
  * Set the window layout
  */
-int AWindowHandler_setWindowLayout(AWindowHandler *p_awh,
-                                   int i_width, int i_height,
-                                   int i_visible_width, int i_visible_height,
-                                   int i_sar_num, int i_sar_den);
+int AWindowHandler_setVideoLayout(AWindowHandler *p_awh,
+                                  int i_width, int i_height,
+                                  int i_visible_width, int i_visible_height,
+                                  int i_sar_num, int i_sar_den);
 
 /**
  * Construct a new Java SurfaceTexture to stream images to a given OpenGL
@@ -162,12 +162,12 @@ int AWindowHandler_setBuffersGeometry(AWindowHandler *p_awh, enum AWindow_ID id,
 
 /**
- * Set the window layout
+ * Set the video layout
  */



More information about the vlc-commits mailing list